@@ -10,7 +10,7 @@ require(tcltk) || stop("tcltk support is absent")
     xmax <- 20
     assign("xmax", tclVar(xmax), envir = slider.env)
         
-    dev.new(height=4,width=8);par(mfrow=c(1,2),mar=c(4.4,4.5,1,0.5),cex=.85);layout(matrix(c(1,2), 1, 2, byrow = TRUE))
+    dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1.5,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
     norm.refresh <- function(...) {
         nu <- as.numeric(evalq(tclvalue(nu), envir = slider.env))
         xmin <- as.numeric(evalq(tclvalue(xmin), envir = slider.env))
@@ -21,6 +21,7 @@ require(tcltk) || stop("tcltk support is absent")
         dev.hold()
         plot(xx, yy, type = "l", xlim = c(xmin, xmax), ylab = "f(x)", xlab = "x")
         plot(xx, y1, type = "l", xlim = c(xmin, xmax), ylab = "F(x)", xlab = "x")
+        mtext(bquote(paste(italic(X), " ~ ", chi^2, "(", .(nu), ")", sep = "")), outer = TRUE, side = 3, cex = .9)
         dev.flush()
             }
     tclServiceMode(TRUE)
@@ -72,6 +73,7 @@ require(tcltk) || stop("tcltk support is absent")
         y1 <- pchisq(xx, nu)
         dev.hold()
         plot(xx, yy, type = "l", xlim = c(xmin, xmax),ylab = "f(x)", xlab = "x")
+        mtext(bquote(paste(italic(X), " ~ ", chi^2, "(", .(nu), ")", sep = "")), line = 1, side = 3)
         dev.flush()
                     }
     tclServiceMode(TRUE)
