@@ -27,8 +27,10 @@ require(tcltk) || stop("tcltk support is absent")
         segments(minX,d,maxX,d) 
         segments(minX,0,minX,d)
         segments(maxX,0,maxX,d)
+         mtext(bquote(paste(italic(X), " ~ ", italic(UNIF), "(", .(minX), ", ", .(maxX),")", sep = "")), line = 1, side = 3)
         dev.flush()           
                     }
+    tclServiceMode(TRUE)
     m <- tktoplevel()
     tkwm.title(m, "Visualizing the Uniform Distribution")
     tkpack(tklabel(m,text="      Visualizing the Uniform Distribution      "))
@@ -82,7 +84,7 @@ require(tcltk) || stop("tcltk support is absent")
     assign("xmax", tclVar(xmax), envir = slider.env)
      
     
-    dev.new(height=4,width=8);par(mfrow=c(1,2),mar=c(4.4,4.5,1,0.5),cex=.85);layout(matrix(c(1,2), 1, 2, byrow = TRUE))
+    dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
     norm.refresh <- function(...) {
         minX <- as.numeric(evalq(tclvalue(minX), envir = slider.env))
         maxX <- as.numeric(evalq(tclvalue(maxX), envir = slider.env))
@@ -98,8 +100,10 @@ require(tcltk) || stop("tcltk support is absent")
         segments(minX,0,minX,d)
         segments(maxX,0,maxX,d)
         plot(xx, y1, type = "l", xlim = c(xmin, xmax), ylab = "F(x)", xlab = "x")
+        mtext(bquote(paste(italic(X), " ~ ", italic(UNIF), "(", .(minX), ", ", .(maxX),")", sep = "")), outer = TRUE, side = 3, cex = .9)
         dev.flush()
             }
+    tclServiceMode(TRUE)
     m <- tktoplevel()
     tkwm.title(m, "Visualizing the Uniform Distribution")
     tkpack(tklabel(m,text="      Visualizing the Uniform Distribution      "))
