@@ -22,6 +22,7 @@ tclServiceMode(TRUE)
         yy <- dweibull(xx, theta, beta)
         dev.hold()
         plot(xx, yy, type = "l", xlim = c(xmin, xmax), ylab = "f(x)", xlab = "x")
+        mtext(bquote(paste(italic(X), " ~ ", italic(WEI), "(", .(beta), ", ", .(theta),")", sep = "")), side = 3, line = 1)
         dev.flush()          
                     }
     m <- tktoplevel()
@@ -77,7 +78,7 @@ tclServiceMode(TRUE)
     xmax <- 30
     assign("xmax", tclVar(xmax), envir = slider.env)
            
-   dev.new(height=4,width=8);par(mfrow=c(1,2),mar=c(4.4,4.5,1,0.5),cex=.85);layout(matrix(c(1,2), 1, 2, byrow = TRUE))
+   dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
    norm.refresh <- function(...) {
         theta <- as.numeric(evalq(tclvalue(theta), envir = slider.env))
         beta <- as.numeric(evalq(tclvalue(beta), envir = slider.env))
@@ -89,6 +90,7 @@ tclServiceMode(TRUE)
         dev.hold()
         plot(xx, yy, type = "l", xlim = c(xmin, xmax), ylab = "f(x)", xlab = "x")
         plot(xx, y1, type = "l", xlim = c(xmin, xmax), ylab = "F(x)", xlab = "x")
+        mtext(bquote(paste(italic(X), " ~ ", italic(WEI), "(", .(beta), ", ", .(theta),")", sep = "")), outer = TRUE, side = 3, cex = .9)
         dev.flush()          
                     }
     m <- tktoplevel()
