@@ -2,6 +2,7 @@
 
 selftest.pdfs.tck1<-function(){
 require(tcltk) || stop("tcltk support is absent")
+tclServiceMode(FALSE)
 tt <- tktoplevel()
  have_ttk <- as.character(tcl("info", "tclversion")) >= 
             "8.5"
@@ -50,13 +51,14 @@ tkgrid(OK.but,columnspan=2)
 tkgrid(tklabel(tt,text=""))
 tkgrid(tkbutton(tt,text="Next question",command=substitute(selftest.pdfs.tck2())),
 tkbutton(tt,text="Exit",command=function()tkdestroy(tt)),sticky ="w")
-tkfocus(tt)
+invisible(tclServiceMode(TRUE))
 }
 
 
 
 selftest.pdfs.tck2<-function(){
 require(tcltk) || stop("tcltk support is absent")
+tclServiceMode(FALSE)
 tt <- tktoplevel()
  have_ttk <- as.character(tcl("info", "tclversion")) >= 
             "8.5"
@@ -104,5 +106,5 @@ OK.but <- tkbutton(tt,text="OK",command=OnOK)
 tkgrid(OK.but,columnspan=2)
 tkgrid(tklabel(tt,text=""))
 tkgrid(tkbutton(tt,text="Next question",command=function()tkmessageBox(message="No further questions.")),tkbutton(tt,text="Exit",command=function()tkdestroy(tt)),sticky ="w")
-tkfocus(tt)
+invisible(tclServiceMode(TRUE))
 }
\ No newline at end of file
