@@ -85,7 +85,7 @@ tkwm.title(tt, "Self-test, Sampling Distributions")
 tkgrid(tklabel(tt,text=""))
 tkgrid(tklabel(tt, text = "Which of the following describes the Central Limit Theorem?"), columnspan = 2)
 tkgrid(tklabel(tt,text=""))
-tkgrid(tklabel(tt,text="  a.    If Y ~ N(\u0232, \u03c3\u00b2), then \u0232 ~ N(\u03bc, \u03c3\u00b2)."),rb1, sticky = "w")
+tkgrid(tklabel(tt,text="  a.    If Y ~ N(\u0232, \u03c3\u00b2), then \u0232 ~ N(\u03bc, \u03c3\u00b2/n)."),rb1, sticky = "w")
 tkgrid(tklabel(tt,text="  b.    If the sample size from Y is large, then the variance for the sampling distribution of \u0232 will be small."),rb2, sticky = "w")
 tkgrid(tklabel(tt,text="  c.    Even if Y is not normal, if the sample size from Y is large, then \u0232 will be approximately normal."),rb3, sticky = "w")
 tkgrid(tklabel(tt,text="  d.    All of the above."),rb4, sticky = "w")
